LocationData class

Constructors

LocationData({required double latitude, required double longitude, double? accuracy, double? altitude, double? speed, double? heading, required DateTime timestamp, String? provider})
LocationData.fromMap(Map<String, dynamic> map)
factory

Properties

accuracy double?
final
altitude double?
final
hashCode int
The hash code for this object.
no setterinherited
heading double?
final
latitude double
final
longitude double
final
provider String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double?
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited