MyBackgroundGeolocation class

Constructors

MyBackgroundGeolocation()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

onError Stream<String>
Error stream getter
no setter
onLocation Stream<LocationData>
Location stream getter
no setter

Static Methods

clearLocations() Future<bool>
Clear all stored locations
getCurrentPosition() Future<LocationData?>
Get current position
getLocations({int? limit}) Future<List<LocationData>>
Get stored locations from database
initialize() Future<void>
Initialize the plugin
isTracking() Future<bool>
Check if location tracking is active
start(MyBackgroundGeolocationConfig config) Future<bool>
Start location tracking
stop() Future<bool>
Stop location tracking
sync(String apiUrl, {String? userId, Map<String, String>? headers}) Future<bool>
Sync locations to API