MyBackgroundGeolocationConfig class

Constructors

MyBackgroundGeolocationConfig({int interval = 10000, double distanceFilter = 50.0, String desiredAccuracy = 'HIGH', String? apiUrl, String? userId, Map<String, String>? headers})

Properties

apiUrl String?
final
desiredAccuracy String
final
distanceFilter double
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
interval int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited